@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 
-
-use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK};
+use vars qw{$VERSION};
+use vars qw{ @ISA @EXPORT @EXPORT_OK };
 BEGIN {
-	$VERSION = '0.83';
+	$VERSION   = '0.84';
 	@ISA       = qw{ Exporter };
 	@EXPORT    = qw{};
 	@EXPORT_OK = qw{};
